==> 1.5.3.zip: 1.5.3/diario/index.php <==
<?php
/************************************************************
copyrigth Claudio cardinale 2004-2011 tutti i diritti riservati
contatti: 	cardi@thecsea.it(o http://www.thecsea.it)
versione :	1.5.3
data:		30/01/2011 19:09
*************************************************************/
//dichiarazioni ed inclusioni
header("Content-Type: text/html; charset=utf-8");
require_once "include/classi.php";
$db = new Spec();
$invia = $db->p_null('invia');
$giorno = $db->p_null('giorno');
$ora = $db->p_null('ora');
$materia = $db->p_null('materia');
$compito = $db->p_null('compito');
$vecchi = $db->g_null('vecchi');

//controlli
if($vecchi == "")
	$vecchi = 0;

//scrittura
if($invia=="invia"){
	$compito = $db->check_sql($compito);
	$data = explode("/",$giorno);
	$ora = explode(".",$ora);
	$data = mktime($ora[0],$ora[1],0,$data[1],$data[0],$data[2]);
	$db->write($data, $materia, $compito);
}
?>
<html>
<head>
<title>calendario</title>
<link rel="stylesheet" type="text/css" href="include/css/style_data.css" /> 
<script type="text/javascript" src="include/classe_data.js"></script> 
<script type="text/javascript"> 
var giorno;
window.onload = function () {
	giorno  = new Epoch('giorno','popup',document.getElementById('giorno'));
};
function insertAtCaret(obj, text1, text2) {
		if(document.selection) {
			obj.focus();
			var range = document.selection.createRange();

			if(range.parentElement() != obj) {
				return false;
			}
			
			range.colpse;
			range.text = text1+range.text+text2;
			
		} else {
			var start = obj.selectionStart;
			var end   = obj.selectionEnd;

			obj.value = obj.value.substr(0, start) 
				+ text1 
				+ obj.value.substr(start, end)
				+ text2
				+ obj.value.substr(end, obj.value.length);
		}
	}
</script> 
</head>
<body>
<?php
//sincronizzazione
if(($err = $db->sincronizza())=="OK")
	print "sincronizzazione avvenuta con successo<br />\n";
else
	print "errori nella sincronizzazione : ".($err==""?"errore generale di connesione":$err)."<br />\n";
?>
<form method="post" action="?vecchi=<?=$vecchi?>">
data : <input type="text" name="giorno" id="giorno" value="<?=date("d/m/y",time())?>"><br />
ora : 
<select name="ora">
<option value="0.0" selected="selected">selezionare un ora...</option>
<option value="8.0">1°</option>
<option value="9.0">2°</option>
<option value="10.0">3°</option>
<option value="11.10">4°</option>
<option value="12.0">5°</option>
<option value="13.0">6°</option>
</select> <br />
materia : 
<select name="materia">
<option value="0" selected="selected">selezionare una materia...</option>
<?php
$materie=$db->read_m();
for($i=0;$i<count($materie);$i++)
	print "<option value=\"".$materie[$i][0]."\">".$materie[$i][1]."</option>\n";
?>
</select>
<a href="javascript:insertAtCaret(document.getElementById('compito'), '[colorato]','[/colorato]')">colorato</a><br />
compito : <textarea name="compito" id="compito" cols="100" rows="5"></textarea><br />
<input type="submit" name="invia" value="invia"><br />
</form>
<?php
$tempo = time();
//$tempo = mktime(10,10,10,9,15,10);
$time_zone = date("O", $tempo);
$sec_g = getdate($tempo);
$sec_g = $sec_g["seconds"]+$sec_g["minutes"]*60+$sec_g["hours"]*3600;
$limite = (mktime(0,0,0,6,11,11)-$tempo+$sec_g)/86400+1;
//print $limite = (mktime(0,0,0,12,3,10)-$tempo+$sec_g)/86400+1;
print "<p><a href=\"?vecchi=0\">mostra i compiti da oggi in poi</a></p>\n<p><a href=\"?vecchi=".($vecchi+7)."\">mostra giorni indietro</a></p>\n<table>\n";
for($k=-$vecchi;$k<$limite;$k++){
	if(date("O", ($tempo+86400*$k-$sec_g))<$time_zone)
		$add_time_zone = +3600;
	elseif(date("O", ($tempo+86400*$k-$sec_g))==$time_zone)
		$add_time_zone = 0;
	else
		$add_time_zone = -3600;
	print "<tr>\n<td colspan=\"3\"><a href=\"inserisci.php?giorno=".date("d/m/y", ($tempo+86400*$k-$sec_g+$add_time_zone))."&vecchi=".$vecchi."\">".$db->nome_giorno(date("w", ($tempo+86400*$k-$sec_g+$add_time_zone)))." ".date("(d - m - Y)", ($tempo+86400*$k-$sec_g+$add_time_zone))."</a> :</td>\n</tr>\n";
	$results = $db->read($tempo+86400*$k-$sec_g+$add_time_zone);
	if($results === false)
		print "<tr>\n<td colspan=\"3\">niente</td>\n</tr>\n";
	else
		for($i=0;$i<count($results);$i++)
			print "<tr>\n<td>".date("H:i",$results[$i][1])."&nbsp;".$results[$i][2]."</td>\n<td>".$results[$i][3]."</td>\n<td><a href=\"modifica.php?id=".$results[$i][0]."&vecchi=".$vecchi."\">modifica</a>&nbsp;<a href=\"elimina.php?id=".$results[$i][0]."&vecchi=".$vecchi."\">elimina</a></td>\n</tr>\n";
}
print "</table>";
?>
</body>
</html>
<?php
$db = 0;
?>

==> 1.5.4.zip: 1.5.4/diario/index.php <==
<?php
/************************************************************
copyrigth Claudio cardinale 2004-2011 tutti i diritti riservati
contatti: 	cardi@thecsea.it(o http://www.thecsea.it)
versione :	1.5.4
data:		27/03/2011 20:23
*************************************************************/
//dichiarazioni ed inclusioni
header("Content-Type: text/html; charset=utf-8");
require_once "include/classi.php";
$db = new Spec();
$invia = $db->p_null('invia');
$giorno = $db->p_null('giorno');
$ora = $db->p_null('ora');
$materia = $db->p_null('materia');
$compito = $db->p_null('compito');
$vecchi = $db->g_null('vecchi');

//controlli
if($vecchi == "")
	$vecchi = 0;

//scrittura
if($invia=="invia"){
	$compito = $db->check_sql($compito);
	$data = explode("/",$giorno);
	$ora = explode(".",$ora);
	$data = mktime($ora[0],$ora[1],0,$data[1],$data[0],$data[2]);
	$db->write($data, $materia, $compito);
}
?>
<html>
<head>
<title>calendario</title>
<link rel="stylesheet" type="text/css" href="include/css/style_data.css" /> 
<script type="text/javascript" src="include/classe_data.js"></script> 
<script type="text/javascript"> 
var giorno;
window.onload = function () {
	giorno  = new Epoch('giorno','popup',document.getElementById('giorno'));
};
function insertAtCaret(obj, text1, text2) {
		if(document.selection) {
			obj.focus();
			var range = document.selection.createRange();

			if(range.parentElement() != obj) {
				return false;
			}
			
			range.colpse;
			range.text = text1+range.text+text2;
			
		} else {
			var start = obj.selectionStart;
			var end   = obj.selectionEnd;

			obj.value = obj.value.substr(0, start) 
				+ text1 
				+ obj.value.substr(start, end)
				+ text2
				+ obj.value.substr(end, obj.value.length);
		}
	}
</script> 
</head>
<body>
<?php
//sincronizzazione
if(($err = $db->sincronizza())=="OK")
	print "sincronizzazione avvenuta con successo<br />\n";
else
	print "errori nella sincronizzazione : ".($err==""?"errore generale di connesione":$err)."<br />\n";
?>
<form method="post" action="?vecchi=<?=$vecchi?>">
data : <input type="text" name="giorno" id="giorno" value="<?=date("d/m/y",time())?>"><br />
ora : 
<select name="ora">
<option value="0.0" selected="selected">selezionare un ora...</option>
<option value="8.0">1°</option>
<option value="9.0">2°</option>
<option value="10.0">3°</option>
<option value="11.10">4°</option>
<option value="12.0">5°</option>
<option value="13.0">6°</option>
</select> <br />
materia : 
<select name="materia">
<option value="0" selected="selected">selezionare una materia...</option>
<?php
$materie=$db->read_m();
for($i=0;$i<count($materie);$i++)
	print "<option value=\"".$materie[$i][0]."\">".$materie[$i][1]."</option>\n";
?>
</select>
<a href="javascript:insertAtCaret(document.getElementById('compito'), '[colorato]','[/colorato]')">colorato</a><br />
compito : <textarea name="compito" id="compito" cols="100" rows="5"></textarea><br />
<input type="submit" name="invia" value="invia"><br />
</form>
<?php
$data = getdate();
$limite = round((mktime(0,0,0,$db->fine[1],$db->fine[0],$db->fine[2])-mktime(0,0,0,$data['mon'],$data['mday'],$data['year']))/86400+1);
print "<p><a href=\"?vecchi=0\">mostra i compiti da oggi in poi</a></p>\n<p><a href=\"?vecchi=".($vecchi+7)."\">mostra giorni indietro</a></p>\n<table>\n";
for($k=-$vecchi;$k<$limite;$k++){
	$giorno = mktime(0,0,0,$data['mon'],$data['mday']+$k,$data['year']);
	print "<tr>\n<td colspan=\"3\"><a href=\"inserisci.php?giorno=".date("d/m/y", $giorno)."&vecchi=".$vecchi."\">".$db->nome_giorno(date("w", $giorno))." ".date("(d - m - Y)", $giorno)."</a> :</td>\n</tr>\n";
	$results = $db->read($giorno);
	if($results === false)
		print "<tr>\n<td colspan=\"3\">niente</td>\n</tr>\n";
	else
		for($i=0;$i<count($results);$i++)
			print "<tr>\n<td>".date("H:i",$results[$i][1])."&nbsp;".$results[$i][2]."</td>\n<td>".$results[$i][3]."</td>\n<td><a href=\"modifica.php?id=".$results[$i][0]."&vecchi=".$vecchi."\">modifica</a>&nbsp;<a href=\"elimina.php?id=".$results[$i][0]."&vecchi=".$vecchi."\">elimina</a></td>\n</tr>\n";
}
print "</table>";
?>
</body>
</html>
<?php
$db = 0;
?>
